@@ -1,8 +1,5 @@
 package App::datecalc;
 
-our $DATE = '2018-02-21'; # DATE
-our $VERSION = '0.08'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
@@ -12,6 +9,11 @@ use DateTime::Format::ISO8601;
 use MarpaX::Simple qw(gen_parser);
 use Scalar::Util qw(blessed);
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2023-02-18'; # DATE
+our $DIST = 'App-datecalc'; # DIST
+our $VERSION = '0.090'; # VERSION
+
 # XXX there should already be an existing module that does this
 sub __fmtduriso {
     my $dur = shift;
@@ -459,7 +461,7 @@ App::datecalc - Date calculator
 
 =head1 VERSION
 
-This document describes version 0.08 of App::datecalc (from Perl distribution App-datecalc), released on 2018-02-21.
+This document describes version 0.090 of App::datecalc (from Perl distribution App-datecalc), released on 2023-02-18.
 
 =head1 SYNOPSIS
 
@@ -572,14 +574,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-dateca
 
 Source repository is at L<https://github.com/perlancar/perl-App-datecalc>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-datecalc>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<DateTime> and L<DateTime::Format::ISO8601>, the backend modules used to do the
@@ -597,11 +591,53 @@ format.
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTORS
+
+=for stopwords Jeffrey Kegler Steven Haryanto
+
+=over 4
+
+=item *
+
+Jeffrey Kegler <JKEGL@cpan.org>
+
+=item *
+
+Steven Haryanto <stevenharyanto@gmail.com>
+
+=back
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2016, 2015, 2014 by perlancar@cpan.org.
+This software is copyright (c) 2023, 2018, 2016, 2015, 2014 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-datecalc>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
